local VERSION = tonumber(("$Revision: 32429 $"):match("%d+"))

local PitBull = PitBull
local PitBull_PvP = PitBull:NewModule("PvP", "AceEvent-2.0")
local self = PitBull_PvP
if PitBull.revision < VERSION then
	PitBull.version = "r" .. VERSION
	PitBull.revision = VERSION
	PitBull.date = ("$Date: 2007-04-12 05:54:17 -0400 (Thu, 12 Apr 2007) $"):match("%d%d%d%d%-%d%d%-%d%d")
end

-- localization placeholder
local L = setmetatable({}, {__index = function(self, key) self[key] = key; return key end })

local new, del, newHash = PitBull.new, PitBull.del, PitBull.newHash
local newFrame, delFrame = PitBull.newFrame, PitBull.delFrame

PitBull_PvP:RegisterPitBullChildFrames('pvpIcon')

function PitBull_PvP:OnInitialize()
	self.db = PitBull:AcquireDBNamespace("PvP")
	PitBull:RegisterDefaults("PvP", "profile", {
		groups = {
			['*'] = {},
		},
	})
end

function PitBull_PvP:OnEnable()
	self:RegisterEvent("UPDATE_FACTION", "Update")
	self:RegisterEvent("PLAYER_FLAGS_CHANGED", "Update")
	self:RegisterEvent("UNIT_FACTION", "Update")
end

function PitBull_PvP:Update(unit, noPet)
	if not unit then
		unit = "player"
	end
	
	local frame = PitBull:GetUnitFrame(unit)
	if frame then
		
		if self.db.profile.groups[frame.group].ignore then
			if frame.pvpIcon then
				frame.pvpIcon = delFrame(frame.pvpIcon)
				PitBull:UpdateLayout(frame)
			end
			return
		end
		
		local has = false
		
		if UnitIsPVPFreeForAll(unit) then
			has = 'FFA'
		else
			local faction = UnitFactionGroup(unit)
			if faction and UnitIsPVP(unit) then
				has = faction
			end
		end
		
		if has then
			if not frame.pvpIcon then
				frame.pvpIcon = newFrame("Texture", frame.overlay, "ARTWORK")
				
				PitBull:UpdateLayout(frame)
			end
			frame.pvpIcon:SetTexture("Interface\\TargetingFrame\\UI-PVP-" .. has)
		else
			if frame.pvpIcon then
				frame.pvpIcon = delFrame(frame.pvpIcon)

				PitBull:UpdateLayout(frame)
			end
		end
	end
	
	if not noPet then
		if unit == "player" then
			self:Update("pet")
		else
			local num = unit:match("^party(%d)$")
			if num then
				self:Update("partypet" .. num)
			end
		end
	end
end

function PitBull_PvP:OnUpdateFrame(unit, frame)
	self:Update(unit, true)
end

function PitBull_PvP:OnClearUnitFrame(unit, frame)
	if frame.pvpIcon then
		frame.pvpIcon = delFrame(frame.pvpIcon)
	end
end

function PitBull_PvP:OnUnknownLayout(unit, frame)
	frame.pvpIcon:SetPoint("CENTER", frame, "TOPRIGHT", 0, 0)
	frame.pvpIcon:SetWidth(27)
	frame.pvpIcon:SetHeight(27)
end

local function getIgnored(group)
	return PitBull_PvP.db.profile.groups[group].ignore
end
local function setIgnored(group, value)
	PitBull_PvP.db.profile.groups[group].ignore = value
	if value then
		for unit,frame in PitBull:IterateUnitFramesByGroup(group) do
			if frame.pvpIcon then
				frame.pvpIcon = delFrame(frame.pvpIcon)
			end
		end
	else
		for unit in PitBull:IterateUnitFramesByGroup(group) do
			PitBull_PvP:Update(unit)
		end
	end
end
PitBull_PvP:RegisterPitBullOptionsMethod(function(group)
	return {
		name = L["PvP Icon"],
		desc = L["PvP Icon"],
		type = 'group',
		args = {
			ignore = {
				type = 'toggle',
				name = L["Disable PvP Icon"],
				desc = L["Disable PvP Icon"],
				get = getIgnored,
				set = setIgnored,
				passValue = group,
			},
		}
	}
end)
